#!/usr/bin/env python
# -*- coding: utf-8 -*-

import i18n
import yaml
from actions import Actions
from devdoo_services import DevdooServices
from devdoo_databases import DevdooDatabases
from check import Check
from config import Config
from console import Console
from convert import Convert
from core import Core
from devdoo_brokers import DevdooBrokers
from database import DataBase
from datafilter import DataFilter
from datarest import DataRest
from endpoint import Endpoint
from package import Package
from datarest_db import DataRestDB
from service import Service
from service_db import ServiceDB
from status import Status
from validate import Validate



#docker exec -it 4551555545454 python ./pastas/add_services.py