#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(name='packagetest90',
      version='0.90',
      description='Test3',
      url='http://github.com/storborg/funniest',
      author='PulStar',
      author_email='pulstar@gmail.com',
      license='MIT',
      packages=['devdoo', 'devdoo/i18n', 'devdoo/yaml'],
      zip_safe=False)
